.. _support:

Support
=======
Please keep in mind that the issues on GitHub are reserved for bugs and
feature requests. If you have general or usage questions about Eve, there
are several options:

Stack Overflow
--------------
`Stack Overflow`_ has a eve tag. It is generally followed by Eve developers
and users.

Mailing List
------------
The `mailing list`_ is intended to be a low traffic resource for both
developers/contributors and API maintainers looking for help or requesting
feedback.

IRC
---
There is an official Freenode channel for Eve at `#python-eve
<irc://irc.freenode.net/python-eve>`_.

File an Issue
-------------
If you notice some unexpected behavior in Eve, or want to see support for a new
feature, `file an issue on GitHub
<https://github.com/pyeve/eve/issues>`_.

.. _`mailing list`: https://groups.google.com/forum/#!forum/python-eve
.. _`Stack Overflow`: https://stackoverflow.com/questions/tagged/eve
